@@ -1,7 +1,7 @@
 package Validator::Custom;
 use Object::Simple -base;
 use 5.008001;
-our $VERSION = '1.02';
+our $VERSION = '1.0201';
 
 use Carp 'croak';
 use Validator::Custom::Validation;
@@ -266,9 +266,7 @@ sub _parse_constraint {
   return $cinfo;
 }
 
-# DEPRECATED!
 has shared_rule => sub { [] };
-# DEPRECATED!
 __PACKAGE__->attr('constraints' => sub { {} });
 
 # Version 0 method
@@ -397,8 +395,6 @@ sub validate {
   
   # Shared rule
   my $shared_rule = $self->shared_rule;
-  warn "Validator::Custom::shared_rule is DEPRECATED!"
-    if @$shared_rule;
   
   if (ref $rule eq 'Validator::Custom::Rule') {
     $self->rule_obj($rule);
@@ -773,7 +769,27 @@ EOS
 
 =head1 NAME
 
-Validator::Custom - HTML form Validation, simple and good flexibility
+Validator::Custom - HTML form validation. Simple and good flexibility
+
+=head1 DESCRIPTION
+
+L<Validator::Custom> is a validator for HTML form.
+
+=over 4
+
+=item *
+
+1. B<Checking functions:> C<ascii_graphic>, C<int>, C<number>, C<in>. You can also add your checking function.
+
+=item *
+
+2. B<Filtering functions:> C<trim>, C<remove_blank>. You can also add your filtering function.
+
+=item *
+
+3. B<Validation object:> Save each validation result and check if all data is valid.
+
+=back
 
 =head1 SYNOPSIS
 
@@ -849,48 +865,16 @@ Validator::Custom - HTML form Validation, simple and good flexibility
     my $messages_h = $validation->messages_to_hash;
   }
   
-=head1 DESCRIPTION
+=head1 1. Basic usage
 
-L<Validator::Custom> is a validator for HTML form
-with simple and good flexibility.
-
-The features are the following ones.
-
-=over 4
-
-=item *
-
-Sevral checking functions are available by default, C<ascii_graphic>,
-C<int>, C<number>, C<in>.
-
-=item *
-
-Several filtering functions are available by default, such as C<trim>, C<remove_blank>.
-
-=item *
-
-You can add your own checking and filtering function.
-
-=item *
-
-Simple validation object is available.
-You can add failed parameter names
-and the messages keeping the order of validation.
-
-=back
-
-=head1 GUIDE
-
-=head2 1. Basic usage
-
-=head3 1. Create a new Validator::Custom object
+=head2 1. Create a new Validator::Custom object
 
 At first, create L<Validator::Custom> object using C<new> method.
 
   use Validator::Custom;
   my $vc = Validator::Custom->new;
 
-=head3 2. Prepare input data for validation
+=head2 2. Prepare input data for validation
 
 Next, prepare input data.
 
@@ -899,7 +883,7 @@ Next, prepare input data.
   my $price = ' 19.23 ';
   my $favorite = ['001', '002'];
 
-=head3 3. Create a new validation object
+=head2 3. Create a new validation object
 
 Next, create a new validation object using C<validation> method.
 
@@ -908,7 +892,7 @@ Next, create a new validation object using C<validation> method.
 This is L<Validator::Custom::Validation> object
 to store failed parameter names and the messages.
 
-=head3 4. Validate input data
+=head2 4. Validate input data
 
   # Check if id is integer
   if (!$vc->check($id, 'int')) {
@@ -947,7 +931,7 @@ You can use C<check_each> method to check each value of favorite.
 If you see default checks and filter,
 see L<Validator::Custom/"CHECKING FUNCTIONS"> and L<Validator::Custom/"FILTERING FUNCTIONS">.
 
-=head2 2. Manipulate validation object
+=head1 2. Manipulate validation object
 
 If you check all input data is valid, use C<is_valid> method.
   
@@ -988,9 +972,9 @@ You can get all failed names and the messages as hash reference using C<messages
 
 See also L<Validator::Custom::Validation>.
 
-=head2 3. Advanced tequnique
+=head1 3. Advanced tequnique
 
-=head3 1. Add checking function
+=head2 1. Add checking function
 
 You can add your own checking function using C<add_check> method if you need.
 
@@ -1013,7 +997,7 @@ Third argument is the argument of checking function.
 
 Your Checking function must return true or false value.
 
-=head3 2. Add filtering function
+=head2 2. Add filtering function
 
 You can add your filtering function by C<add_filter> method if you need.
 
@@ -1034,18 +1018,18 @@ Third argument is the argument of filtering function.
 
 Your filtering function must return the result of filtering.
 
-=head1 CHECKING FUNCTIONS
+=head1 Checking functions
 
 L<Validator::Custom> have the following default checking functions.
 You can call any checking function by C<check> method.
 
 =head2 int
 
+Check if the value is integer value.
+
   my $value = 19;
   my $is_valid = $vc->check($value, 'int');
 
-Check if the value is integer value.
-
 Example of valid values:
 
   "-10"
@@ -1061,11 +1045,11 @@ If you also need to check the range of value, you can write the following way.
   my $is_valid =  $vc->check($value, 'int') && $value > 0;
 
 =head2 number
-  
-  my $is_valid = $vc->check($value, 'number');
 
 Check if the value is number.
 Number means integer or decimal.
+  
+  my $is_valid = $vc->check($value, 'number');
 
 Example of valid values:
 
@@ -1098,12 +1082,12 @@ Example of invalid values:
   '-100.7891'
 
 =head2 ascii_graphic
-  
-  my $is_valid = $vc->check($value, 'ascii');
-  
+
 Check if the value is Ascii graphic characters(hex 21-7e).
 Generally, C<ascii_graphic> function is used to
 check the characters of a password.
+  
+  my $is_valid = $vc->check($value, 'ascii');
 
 Example of valid values:
 
@@ -1115,12 +1099,12 @@ Example of invalid values:
   "\taaa"
 
 =head2 in
+
+Check if the value is one of the given values.
   
   my $value = '001';
   my $is_valid = $vc->check($value, 'in', ['001', '002', '003']);
 
-Check if the value is one of the given values.
-
 Example of valid values:
 
   '001'
@@ -1132,18 +1116,18 @@ Example of invalid values:
   '004'
   '005'
 
-=head1 FILTERING FUNCTIONS
+=head1 Filtering functions
 
 L<Validator::Custom> have the following default filtering functions.
 You can call any filtering function using C<filter> method.
 
 =head2 trim
 
-  my $new_value = $vc->filter($value, 'trim');
-
 Trim leading and trailing white space.
 Note that trim function remove unicode space character, not only C<[ \t\n\r\f]>.
 
+  my $new_value = $vc->filter($value, 'trim');
+
 Filtering example:
 
   Input : '  　Ken  '
@@ -1151,32 +1135,32 @@ Filtering example:
 
 =head2 remove_blank
 
-  my $new_values = $vc->filter($values, 'remove_blank');
-
 Remove blank character and undefined value from array reference.
 
+  my $new_values = $vc->filter($values, 'remove_blank');
+
 Filtering example:
 
   Input : [1, 2, '', undef, 4]
   Output: [1, 2, 4]
 
-=head1 METHODS
+=head1 Methods
 
 L<Validator::Custom> inherits all methods from L<Object::Simple>
 and implements the following new ones.
 
 =head2 new
 
-  my $vc = Validator::Custom->new;
-
 Create a new L<Validator::Custom> object.
 
+  my $vc = Validator::Custom->new;
+
 =head2 add_check
 
-  $vc->add_check(int => sub { ... });
-
 Add a checking function.
 
+  $vc->add_check(int => sub { ... });
+
 Example:
   
   $vc->add_check(
@@ -1198,10 +1182,10 @@ Your Checking function must return true or false value.
 
 =head2 add_filter
 
-  $vc->add_filter(trim => sub { ... });
-
 Add a filtering function. 
 
+  $vc->add_filter(trim => sub { ... });
+
 Example:
 
   $vc->add_filter(
@@ -1217,45 +1201,45 @@ Example:
 
 =head2 check
 
+Execute a checking function.
+
   my $is_valid = $vc->check($value, 'int');
   my $is_valid = $vc->check($value, 'int', $arg);
 
-Execute a checking function.
-
 First argument is the value for checking.
 Second argument is the name of the checking funcion.
 Third argument is the argument of the checking function.
 
 =head2 check_each
 
-  my $is_valid = $vc->check_each($values, 'int');
-  my $is_valid = $vc->check_each($values, 'int', $arg);
-
 Execute a checking function to all elements of array reference.
 If more than one element is invalid, C<check_each> method return false.
 
+  my $is_valid = $vc->check_each($values, 'int');
+  my $is_valid = $vc->check_each($values, 'int', $arg);
+
 First argument is the values for checking, which must be array reference.
 Second argument is the name of the checking funcion.
 Third argument is the argument of the checking function.
 
 =head2 filter
 
+Execute a filtering function.
+
   my $new_value = $vc->filter($value, 'trim');
   my $new_value = $vc->filter($value, 'trim', $arg);
 
-Execute a filtering function.
-
 First argument is the value for filtering.
 Second argument is the name of the filtering funcion.
 Third argument is the argument of the filtering function.
 
 =head2 filter_each
 
+Execute a filtering function to all elements of array reference.
+
   my $new_values = $vc->filter_each($values, 'trim');
   my $new_values = $vc->filter_each($values, 'trim', $arg);
 
-Execute a filtering function to all elements of array reference.
-
 First argument is the values for filtering, which must be array reference.
 Second argument is the name of the filtering funcion.
 Third argument is the argument of the filtering function.
@@ -1540,7 +1524,7 @@ L<http://github.com/yuki-kimoto/Validator-Custom>
 
 =head1 COPYRIGHT & LICENCE
 
-Copyright 2009-2015 Yuki Kimoto, all rights reserved.
+Copyright 2009-2017 Yuki Kimoto, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
