@@ -1,3 +1,4 @@
+# Version 0 module
 package Validator::Custom::Constraint;
 
 use strict;
@@ -124,8 +125,6 @@ sub datetime_to_timepiece {
 sub decimal {
   my ($value, $digits_tmp) = @_;
   
-  $DB::single = 1;
-  
   # 桁数情報を整理
   my $digits;
   if (defined $digits_tmp) {
@@ -356,3 +355,7 @@ sub trim_uni_trail {
 }
 
 1;
+
+=head1 NAME
+
+Validator::Custom::Constraint - Constrint functions
