@@ -1,87 +1,23 @@
+# Version 0 module
 package Validator::Custom::Result;
 use Object::Simple -base;
 
 use Carp 'croak';
 
 # Attrbutes
-has data => sub { {} },
-  missing_params => sub { [] },
-  raw_data  => sub { {} };
-
-# Default message
-our $DEFAULT_MESSAGE = 'Error message not specified';
-
-sub error_reason {
-
-  warn "Validator::Custom::Result error_reason is DEPRECATED!.";
-
-  my ($self, $name) = @_;
-  
-  # Parameter name not specified
-  croak 'Parameter name must be specified'
-    unless $name;
-  
-  # Error reason
-  return $self->{_error_infos}->{$name}{reason};
-}
-
-sub has_invalid {
-  my $self = shift;
-  
-  # Has invalid parameter?
-  return keys %{$self->{_error_infos}} ? 1 : 0;
-}
-
-sub has_missing { @{shift->missing_params} ? 1 : 0 }
-
-sub invalid_params {
-  my $self = shift;
-  
-  # Invalid parameter names
-  my @invalid_params;
-  foreach my $name (@{$self->invalid_rule_keys}) {
-      my $param = $self->{_error_infos}->{$name}{original_key};
-      $param = [$param] unless ref $param eq 'ARRAY';
-      push @invalid_params, @$param;
-  }
-  
-  return \@invalid_params;
-}
-
-sub invalid_rule_keys {
-  my $self = shift;
-  
-  # Invalid rule keys
-  my $error_infos = $self->{_error_infos};
-  my @invalid_rule_keys = sort { $error_infos->{$a}{position} <=>
-    $error_infos->{$b}{position} } keys %$error_infos;
-  
-  return \@invalid_rule_keys;
-}
+has data => sub { {} };
+has raw_data  => sub { {} };
+has missing_params => sub { [] };
 
 sub is_valid {
   my ($self, $name) = @_;
-  
-  # Deprecated
-  unless (defined $name) {
-    warn "Validator::Custom::Result is_valid() method without argument" .
-      " is deprecated. Use is_ok()";
-    return $self->is_ok;
+ 
+  if (defined $name) {
+    return exists $self->{_error_infos}->{$name} ? 0 : 1;
+  }
+  else {
+    return !(keys %{$self->{_error_infos}}) ? 1 : 0;
   }
-  
-  return exists $self->{_error_infos}->{$name} ? 0 : 1;
-}
-
-sub is_ok {
-  my $self = shift;
-  
-  # Is ok?
-  return !$self->has_invalid && !$self->has_missing ? 1 : 0;
-}
-
-sub loose_data {
-  my $self = shift;
-  return {%{$self->raw_data}, %{$self->data}};
 }
 
 sub message {
@@ -93,7 +29,7 @@ sub message {
   
   return $self->{_error_infos}->{$name}{message}
     || $self->{_default_messages}{$name}
-    || $DEFAULT_MESSAGE;
+    || 'Error message not specified';
 }
 
 sub messages {
@@ -124,6 +60,13 @@ sub messages_to_hash {
   return $messages;
 }
 
+sub is_ok {
+  my $self = shift;
+  
+  # Is ok?
+  return !$self->has_invalid && !$self->has_missing ? 1 : 0;
+}
+
 sub to_hash {
   my $self = shift;
   
@@ -138,6 +81,61 @@ sub to_hash {
   return $result;
 }
 
+sub invalid_rule_keys {
+  my $self = shift;
+  
+  # Invalid rule keys
+  my $error_infos = $self->{_error_infos};
+  my @invalid_rule_keys = sort { $error_infos->{$a}{position} <=>
+    $error_infos->{$b}{position} } keys %$error_infos;
+  
+  return \@invalid_rule_keys;
+}
+
+sub has_missing { @{shift->missing_params} ? 1 : 0 }
+
+sub has_invalid {
+  my $self = shift;
+  
+  # Has invalid parameter?
+  return keys %{$self->{_error_infos}} ? 1 : 0;
+}
+
+sub loose_data {
+  my $self = shift;
+  return {%{$self->raw_data}, %{$self->data}};
+}
+
+sub invalid_params {
+  my $self = shift;
+  
+  # Invalid parameter names
+  my @invalid_params;
+  foreach my $name (@{$self->invalid_rule_keys}) {
+      my $param = $self->{_error_infos}->{$name}{original_key};
+      $param = [$param] unless ref $param eq 'ARRAY';
+      push @invalid_params, @$param;
+  }
+  
+  return \@invalid_params;
+}
+
+
+# DEPRECATED!
+sub error_reason {
+
+  warn "Validator::Custom::Result error_reason is DEPRECATED!.";
+
+  my ($self, $name) = @_;
+  
+  # Parameter name not specified
+  croak 'Parameter name must be specified'
+    unless $name;
+  
+  # Error reason
+  return $self->{_error_infos}->{$name}{reason};
+}
+
 # DEPRECATED!
 has error_infos => sub { {} };
 # DEPRECATED!
