@@ -1,44 +1,38 @@
+# Version 0 module
 package Validator::Custom::Rule;
 use Object::Simple -base;
 use Carp 'croak';
 
-has 'topic';
+has 'topic_info' => sub { {} };
 has 'rule' => sub { [] };
 has 'validator';
 
-sub each {
+sub default {
+  my ($self, $default) = @_;
+  
+  $self->topic_info->{default} = $default;
+  
+  return $self;
+}
+
+sub name {
+  my ($self, $name) = @_;
+  
+  $self->topic_info->{name} = $name;
+  
+  return $self;
+}
+
+sub filter {
   my $self = shift;
   
-  if (@_) {
-    $self->topic->{each} = $_[0];
-    return $self;
-  }
-  else {
-    return $self->topic->{each};
-  }
-  
-  return $self;
+  return $self->check(@_)
 }
 
-sub check_or {
-  my ($self, @constraints) = @_;
-  
-  my $constraint_h = {};
-  $constraint_h->{constraint} = \@constraints;
-  
-  my $cinfo = $self->validator->_parse_constraint($constraint_h);
-  $cinfo->{each} = $self->topic->{each};
-  
-  $self->topic->{constraints} ||= [];
-  push @{$self->topic->{constraints}}, $cinfo;
-  
-  return $self;
-}
-
-sub filter { shift->check(@_) }
-
 sub check {
-  my ($self, @constraints) = @_;
+  my $self = shift;
+  
+  my @constraints = @_;
 
   my $constraints_h = [];
   for my $constraint (@constraints) {
@@ -51,28 +45,12 @@ sub check {
       $constraint_h->{constraint} = $constraint;
     }
     my $cinfo = $self->validator->_parse_constraint($constraint_h);
-    $cinfo->{each} = $self->topic->{each};
+    $cinfo->{each} = $self->topic_info->{each};
     push @$constraints_h, $cinfo;
   }
 
-  $self->topic->{constraints} ||= [];
-  $self->topic->{constraints} = [@{$self->topic->{constraints}}, @{$constraints_h}];
-  
-  return $self;
-}
-
-sub copy {
-  my ($self, $copy) = @_;
-  
-  $self->topic->{option}{copy} = $copy;
-  
-  return $self;
-}
-
-sub default {
-  my ($self, $default) = @_;
-  
-  $self->topic->{option}{default} = $default;
+  $self->topic_info->{constraints} ||= [];
+  $self->topic_info->{constraints} = [@{$self->topic_info->{constraints}}, @{$constraints_h}];
   
   return $self;
 }
@@ -80,7 +58,7 @@ sub default {
 sub message {
   my ($self, $message) = @_;
   
-  my $constraints = $self->topic->{constraints} || [];
+  my $constraints = $self->topic_info->{constraints} || [];
   for my $constraint (@$constraints) {
     $constraint->{message} ||= $message;
   }
@@ -88,43 +66,56 @@ sub message {
   return $self;
 }
 
-sub name {
-  my ($self, $result_key) = @_;
+sub topic {
+  my ($self, $key) = @_;
   
-  my $key = $self->topic->{key};
-  $self->topic->{key} = {$result_key => $key};
+  # Create topic
+  my $topic_info = {};
+  $topic_info->{key} = $key;
+  $self->topic_info($topic_info);
+
+  # Add topic to rule
+  push @{$self->rule}, $self->topic_info;
+  
+  return $self;
+}
+
+sub each {
+  my $self = shift;
+  
+  if (@_) {
+    $self->topic_info->{each} = $_[0];
+    return $self;
+  }
+  else {
+    return $self->topic_info->{each};
+  }
   
   return $self;
 }
 
 sub optional {
   my ($self, $key) = @_;
-
-  # Create topic
-  my $topic = {};
-  $topic->{key} = $key;
-  $self->topic($topic);
+  
+  if (defined $key) {
+    # Create topic
+    $self->topic($key);
+  }
   
   # Value is optional
-  $topic->{option}{require} = 0;
-  
-  # Add topic to rule
-  push @{$self->rule}, $topic;
+  $self->rule->[-1]{option}{optional} = 1;
   
   return $self;
 }
 
 sub require {
   my ($self, $key) = @_;
-  
-  # Create topic
-  my $topic = {};
-  $topic->{key} = $key;
-  $self->topic($topic);
-  
-  # Add topic to rule
-  push @{$self->rule}, $topic;
 
+  # Create topic
+  if (defined $key) {
+    $self->topic($key);
+  }
+  
   return $self;
 }
 
@@ -186,6 +177,29 @@ sub parse {
   return $self;
 }
 
+sub copy {
+  my ($self, $copy) = @_;
+
+  $self->topic_info->{option}{copy} = $copy;
+  
+  return $self;
+}
+
+sub check_or {
+  my ($self, @constraints) = @_;
+
+  my $constraint_h = {};
+  $constraint_h->{constraint} = \@constraints;
+  
+  my $cinfo = $self->validator->_parse_constraint($constraint_h);
+  $cinfo->{each} = $self->topic_info->{each};
+  
+  $self->topic_info->{constraints} ||= [];
+  push @{$self->topic_info->{constraints}}, $cinfo;
+  
+  return $self;
+}
+
 1;
 
 =head1 NAME
